@@ -1,5 +1,5 @@
 from __future__ import absolute_import, unicode_literals
-from django.conf.urls.defaults import patterns, url
+from django.conf.urls import patterns, url
 
 from .views import RevisionReapplyView, RevisionListView
 
